Package: 
Version: 0.0.1
Title: Add a title
Description: Describe your application in complete sentences.
Authors@R: 
    c(person("Simon E. H.", "Smart", email = "simon.smart@cantab.net", role = c("aut","cre")))
Depends:
    R (>= 4.1.0),
Imports:
    bslib,
    DT (>= 0.5),
    gargoyle,
    glue,
    knitcitations,
    markdown,
    R6,
    renv,
    rmarkdown,
    shiny (>= 1.8.1),
    shinyalert,
    shinybusy,
    shinyjs,
    shinyWidgets (>= 0.6.0),
    tools
Suggests: 
    shinytest2,
    testthat
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.3
