# Generated by roxygen2: do not edit by hand

export(asyncLog)
export(check_suggests)
export(check_url)
export(create_module)
export(create_template)
export(get_nasa_token)
export(metadata)
export(plot_hist)
export(plot_scatter)
export(printVecAsis)
export(register_module)
export(run_shinyscholar)
export(save_and_load)
export(select_async)
export(select_query)
export(select_user)
export(spurious)
export(writeLog)
