```{asis, echo = {{plot_auto_knit}}, eval = {{plot_auto_knit}}, include = {{plot_auto_knit}}}
Plots the data as a histogram
```

```{r, echo = {{plot_auto_knit}}, include = {{plot_auto_knit}}}
histogram <- plot_hist(raster, {{plot_auto_bins}}, {{plot_auto_pal}}, {{plot_auto_name}})
histogram()
```
