---
title: "intro_tab"
output: html_document
---

#### WORKFLOW

*shinyscholar* (v0.4.5) includes four components, or steps of a possible workflow. Each component includes one or more modules, which are possible analyses for that step.  

**Components:**  

**1.** *Select Data*  
- Obtain vegetation data through an API
- Obtain vegetation data through an API asynchronously
- Upload your own raster data

**2.** *Plot Data*  
- Plot data as a histogram
- Plot data as a scatter plot
- Automatically plot a histogram
- Semi-automatically plot a histogram

**3.** *Reproduce*  
- Download session code  
- Download dependencies
- Download package references 

**4.** *Template*  
- Create a template application
