---
title: "Reproduce"
output: html_document
---

### **Component: Reproduce**

**ORIENTATION**

Scientific practice increasingly emphasizes documentation and reproducibility. *shinyscholar* promotes documentation by allowing users to download  information that includes sources of input data, methodological decisions, and results. One option for the documentation (see Module: *Download Session Code*) is a file that can be re-run in R to reproduce the analyses. Many intermediate and advanced users of R likely will find this file useful as a template for modification. To ensure reproducibility requires the exact same versions of R and dependent packages and these can be downloaded and used to install the same packages later (Module: *Reproduce environment*). Additionally, *shinyscholar* provides citations of the particular R packages (and their versions) used in a given analysis (Module: *Reference Packages*).
