---
title: "team"
output: html_document
---

#### *shinyscholar* was forked from *Wallace* and we are grateful for the original application developers listed on <a href="https://wallaceecomod.github.io/" target="_blank">their website.</a>

## Developers

<a href="https://github.com/simon-smart88" target="_blank">Simon Smart</a> received his PhD in Plant Sciences from the University of Cambridge and is currently a Software Developer in the Department of Population Health Sciences at the University of Leicester where he is developing <a href="https://simon-smart88.github.io/disagapp/" target="_blank">disagapp</a>

<a href="https://timcdlucas.github.io/" target="_blank">Tim Lucas</a>is a lecturer in the Department of Population Health Sciences at the University of Leicester and saw the potential to reuse features from Wallace to create new applications.

<a href="https://www.andersonlab.ccny.cuny.edu/" target="_blank">Robert P. Anderson</a> is a Professor of Biology at City College of New York, CUNY. He managed development of Wallace and provided feedback during the development of Shinyscholar.

<a href="https://deanattali.com/" target="_blank">Dean Attali</a> is an R-Shiny developed who acted as a consultant during the development of Wallace, creating  the modular architecture which is reused in shinyscholar.
