---
title: shinyscholar session `r Sys.Date()`
---

```{r, include=FALSE}
library(knitr)
knit_engines$set(asis = function(options) {
  if (options$echo && options$eval) knit_child(text = options$code)
})
knitr::opts_chunk$set(message = FALSE, warning = FALSE, eval = FALSE)
```

Please find below the R code history from your *shinyscholar* v0.4.5 session. 

You can reproduce your session results by running this R Markdown file in RStudio. 

Each code block is called a "chunk", and you can run them either one-by-one or all at once by choosing an option in the "Run" menu at the top-right corner of the "Source" pane in RStudio. The file can also be rendered into an html file using `rmarkdown::render()` which will contain all of the outputs alongside the code used to generate them.

For more detailed information see <http://rmarkdown.rstudio.com>.

### Package installation

shinyscholar uses the following R packages that must be installed and loaded before starting.
```{r}
library(terra)
library(leaflet)
library(shinyscholar)
```

The *shinyscholar* session code .Rmd file is composed of a chain of module functions that are internal to *shinyscholar*. Each of these functions corresponds to a single module that the user ran during the session. To see the internal code for these module functions, click on the links in the .Rmd file. Users are encouraged to write custom code in the .Rmd directly to modify their analysis, and even modify the module function code to further customize. To see the source code for any module function, just type its name into the R console and press Return.

Your analyses are below.

